# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apex/v1/apex.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'apex/v1/apex.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61pex/v1/apex.proto\x12\x07\x61pex.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xf2\x03\n\x15\x43hatCompletionRequest\x12\x0c\n\x04uids\x18\x01 \x03(\x03\x12&\n\x08messages\x18\x02 \x03(\x0b\x32\x14.apex.v1.ChatMessage\x12\x11\n\x04seed\x18\x03 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04task\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05model\x18\x05 \x01(\tH\x02\x88\x01\x01\x12 \n\x13test_time_inference\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x14\n\x07mixture\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12=\n\x13sampling_parameters\x18\x08 \x01(\x0b\x32\x1b.apex.v1.SamplingParametersH\x05\x88\x01\x01\x12\x1b\n\x0einference_mode\x18\t \x01(\tH\x06\x88\x01\x01\x12\x18\n\x0bjson_format\x18\n \x01(\x08H\x07\x88\x01\x01\x12\x13\n\x06stream\x18\x0b \x01(\x08H\x08\x88\x01\x01\x12\x14\n\x07timeout\x18\x0c \x01(\x03H\t\x88\x01\x01\x42\x07\n\x05_seedB\x07\n\x05_taskB\x08\n\x06_modelB\x16\n\x14_test_time_inferenceB\n\n\x08_mixtureB\x16\n\x14_sampling_parametersB\x11\n\x0f_inference_modeB\x0e\n\x0c_json_formatB\t\n\x07_streamB\n\n\x08_timeout\"\x81\x01\n\x12SamplingParameters\x12\x13\n\x0btemperature\x18\x01 \x01(\x01\x12\r\n\x05top_p\x18\x02 \x01(\x01\x12\x12\n\x05top_k\x18\x03 \x01(\x01H\x00\x88\x01\x01\x12\x16\n\x0emax_new_tokens\x18\x04 \x01(\x03\x12\x11\n\tdo_sample\x18\x05 \x01(\x08\x42\x08\n\x06_top_k\"\xd1\x01\n\x16\x43hatCompletionResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12 \n\x07\x63hoices\x18\x02 \x03(\x0b\x32\x0f.apex.v1.Choice\x12\x0f\n\x07\x63reated\x18\x03 \x01(\x03\x12\r\n\x05model\x18\x04 \x01(\t\x12\x0e\n\x06object\x18\x05 \x01(\t\x12\x14\n\x0cservice_tier\x18\x06 \x01(\t\x12\x1a\n\x12system_fingerprint\x18\x07 \x01(\t\x12\'\n\x05usage\x18\x08 \x01(\x0b\x32\x18.apex.v1.CompletionUsage\"\x8a\x01\n\x06\x43hoice\x12\x15\n\rfinish_reason\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x03\x12)\n\x08logprobs\x18\x03 \x01(\x0b\x32\x17.apex.v1.ChoiceLogprobs\x12/\n\x07message\x18\x04 \x01(\x0b\x32\x1e.apex.v1.ChatCompletionMessage\"\x88\x02\n\x15\x43hatCompletionMessage\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0f\n\x07refusal\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12(\n\x0b\x61nnotations\x18\x04 \x03(\x0b\x32\x13.apex.v1.Annotation\x12+\n\x05\x61udio\x18\x05 \x01(\x0b\x32\x1c.apex.v1.ChatCompletionAudio\x12,\n\rfunction_call\x18\x06 \x01(\x0b\x32\x15.apex.v1.FunctionCall\x12:\n\ntool_calls\x18\x07 \x03(\x0b\x32&.apex.v1.ChatCompletionMessageToolCall\"+\n\nAnnotation\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"W\n\x13\x43hatCompletionAudio\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\x12\x12\n\nexpires_at\x18\x03 \x01(\x03\x12\x12\n\ntranscript\x18\x04 \x01(\t\"/\n\x0c\x46unctionCall\x12\x11\n\targuments\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"^\n\x1d\x43hatCompletionMessageToolCall\x12\n\n\x02id\x18\x01 \x01(\t\x12#\n\x08\x66unction\x18\x02 \x01(\x0b\x32\x11.apex.v1.Function\x12\x0c\n\x04type\x18\x03 \x01(\t\"+\n\x08\x46unction\x12\x11\n\targuments\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xdb\x01\n\x1b\x43hatCompletionChunkResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12%\n\x07\x63hoices\x18\x02 \x03(\x0b\x32\x14.apex.v1.ChunkChoice\x12\x0f\n\x07\x63reated\x18\x03 \x01(\x03\x12\r\n\x05model\x18\x04 \x01(\t\x12\x0e\n\x06object\x18\x05 \x01(\t\x12\x14\n\x0cservice_tier\x18\x06 \x01(\t\x12\x1a\n\x12system_fingerprint\x18\x07 \x01(\t\x12\'\n\x05usage\x18\x08 \x01(\x0b\x32\x18.apex.v1.CompletionUsage\",\n\x0b\x43hatMessage\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"\x83\x01\n\x0b\x43hunkChoice\x12#\n\x05\x64\x65lta\x18\x01 \x01(\x0b\x32\x14.apex.v1.ChoiceDelta\x12\x15\n\rfinish_reason\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x03\x12)\n\x08logprobs\x18\x04 \x01(\x0b\x32\x17.apex.v1.ChoiceLogprobs\"|\n\x0e\x43hoiceLogprobs\x12\x34\n\x07\x63ontent\x18\x01 \x03(\x0b\x32#.apex.v1.ChatCompletionTokenLogprob\x12\x34\n\x07refusal\x18\x02 \x03(\x0b\x32#.apex.v1.ChatCompletionTokenLogprob\"\xa8\x01\n\x0b\x43hoiceDelta\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x37\n\rfunction_call\x18\x02 \x01(\x0b\x32 .apex.v1.ChoiceDeltaFunctionCall\x12\x0f\n\x07refusal\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x30\n\ntool_calls\x18\x05 \x03(\x0b\x32\x1c.apex.v1.ChoiceDeltaToolCall\":\n\x17\x43hoiceDeltaFunctionCall\x12\x11\n\targuments\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x13\x43hoiceDeltaToolCall\x12\r\n\x05index\x18\x01 \x01(\x03\x12\n\n\x02id\x18\x02 \x01(\t\x12\x36\n\x08\x66unction\x18\x03 \x01(\x0b\x32$.apex.v1.ChoiceDeltaToolCallFunction\x12\x0c\n\x04type\x18\x04 \x01(\t\">\n\x1b\x43hoiceDeltaToolCallFunction\x12\x11\n\targuments\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x1a\x43hatCompletionTokenLogprob\x12\r\n\x05token\x18\x01 \x01(\t\x12\r\n\x05\x62ytes\x18\x02 \x03(\x03\x12\x0f\n\x07logprob\x18\x03 \x01(\x01\x12)\n\x0ctop_logprobs\x18\x04 \x03(\x0b\x32\x13.apex.v1.TopLogprob\";\n\nTopLogprob\x12\r\n\x05token\x18\x01 \x01(\t\x12\r\n\x05\x62ytes\x18\x02 \x03(\x03\x12\x0f\n\x07logprob\x18\x03 \x01(\x01\"\xdb\x01\n\x0f\x43ompletionUsage\x12\x19\n\x11\x63ompletion_tokens\x18\x01 \x01(\x03\x12\x15\n\rprompt_tokens\x18\x02 \x01(\x03\x12\x14\n\x0ctotal_tokens\x18\x03 \x01(\x03\x12\x43\n\x19\x63ompletion_tokens_details\x18\x04 \x01(\x0b\x32 .apex.v1.CompletionTokensDetails\x12;\n\x15prompt_tokens_details\x18\x05 \x01(\x0b\x32\x1c.apex.v1.PromptTokensDetails\"\x91\x01\n\x17\x43ompletionTokensDetails\x12\"\n\x1a\x61\x63\x63\x65pted_prediction_tokens\x18\x01 \x01(\x03\x12\x14\n\x0c\x61udio_tokens\x18\x02 \x01(\x03\x12\x18\n\x10reasoning_tokens\x18\x03 \x01(\x03\x12\"\n\x1arejected_prediction_tokens\x18\x04 \x01(\x03\"B\n\x13PromptTokensDetails\x12\x14\n\x0c\x61udio_tokens\x18\x01 \x01(\x03\x12\x15\n\rcached_tokens\x18\x02 \x01(\x03\"\xdb\x01\n\x13WebRetrievalRequest\x12\x0c\n\x04uids\x18\x01 \x03(\x03\x12\x14\n\x0csearch_query\x18\x02 \x01(\t\x12\x15\n\x08n_miners\x18\x03 \x01(\x03H\x00\x88\x01\x01\x12\x16\n\tn_results\x18\x04 \x01(\x03H\x01\x88\x01\x01\x12\x1e\n\x11max_response_time\x18\x05 \x01(\x03H\x02\x88\x01\x01\x12\x14\n\x07timeout\x18\x06 \x01(\x03H\x03\x88\x01\x01\x42\x0b\n\t_n_minersB\x0c\n\n_n_resultsB\x14\n\x12_max_response_timeB\n\n\x08_timeout\"A\n\x0fWebSearchResult\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x10\n\x08relevant\x18\x03 \x01(\t\"A\n\x14WebRetrievalResponse\x12)\n\x07results\x18\x01 \x03(\x0b\x32\x18.apex.v1.WebSearchResult\"i\n\x1fSubmitDeepResearcherJobResponse\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x12\n\nupdated_at\x18\x04 \x01(\t\"\xb8\x01\n\x1cGetDeepResearcherJobResponse\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x12\n\nupdated_at\x18\x04 \x01(\t\x12\x32\n\x06result\x18\x05 \x03(\x0b\x32\".apex.v1.DeepResearcherResultChunk\x12\x12\n\x05\x65rror\x18\x06 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_error\":\n\x19\x44\x65\x65pResearcherResultChunk\x12\x0e\n\x06seq_id\x18\x01 \x01(\x03\x12\r\n\x05\x63hunk\x18\x02 \x01(\t\"-\n\x1bGetDeepResearcherJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\xac\x01\n\x0b\x43hatSession\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tchat_type\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"F\n\x17GetChatSessionsResponse\x12+\n\rchat_sessions\x18\x01 \x03(\x0b\x32\x14.apex.v1.ChatSession\"\xa9\x01\n\x1aUpdateChatAttributeRequest\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\t\x12G\n\nattributes\x18\x02 \x03(\x0b\x32\x33.apex.v1.UpdateChatAttributeRequest.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x1bUpdateChatAttributeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\x86\x05\n\x0b\x41pexService\x12Q\n\x0e\x43hatCompletion\x12\x1e.apex.v1.ChatCompletionRequest\x1a\x1f.apex.v1.ChatCompletionResponse\x12^\n\x14\x43hatCompletionStream\x12\x1e.apex.v1.ChatCompletionRequest\x1a$.apex.v1.ChatCompletionChunkResponse0\x01\x12K\n\x0cWebRetrieval\x12\x1c.apex.v1.WebRetrievalRequest\x1a\x1d.apex.v1.WebRetrievalResponse\x12\x63\n\x17SubmitDeepResearcherJob\x12\x1e.apex.v1.ChatCompletionRequest\x1a(.apex.v1.SubmitDeepResearcherJobResponse\x12\x63\n\x14GetDeepResearcherJob\x12$.apex.v1.GetDeepResearcherJobRequest\x1a%.apex.v1.GetDeepResearcherJobResponse\x12K\n\x0fGetChatSessions\x12\x16.google.protobuf.Empty\x1a .apex.v1.GetChatSessionsResponse\x12`\n\x13UpdateChatAttribute\x12#.apex.v1.UpdateChatAttributeRequest\x1a$.apex.v1.UpdateChatAttributeResponseB1Z/macrocosm-os/rift/constellation_api/gen/apex/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apex.v1.apex_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/macrocosm-os/rift/constellation_api/gen/apex/v1'
  _globals['_UPDATECHATATTRIBUTEREQUEST_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_UPDATECHATATTRIBUTEREQUEST_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_CHATCOMPLETIONREQUEST']._serialized_start=94
  _globals['_CHATCOMPLETIONREQUEST']._serialized_end=592
  _globals['_SAMPLINGPARAMETERS']._serialized_start=595
  _globals['_SAMPLINGPARAMETERS']._serialized_end=724
  _globals['_CHATCOMPLETIONRESPONSE']._serialized_start=727
  _globals['_CHATCOMPLETIONRESPONSE']._serialized_end=936
  _globals['_CHOICE']._serialized_start=939
  _globals['_CHOICE']._serialized_end=1077
  _globals['_CHATCOMPLETIONMESSAGE']._serialized_start=1080
  _globals['_CHATCOMPLETIONMESSAGE']._serialized_end=1344
  _globals['_ANNOTATION']._serialized_start=1346
  _globals['_ANNOTATION']._serialized_end=1389
  _globals['_CHATCOMPLETIONAUDIO']._serialized_start=1391
  _globals['_CHATCOMPLETIONAUDIO']._serialized_end=1478
  _globals['_FUNCTIONCALL']._serialized_start=1480
  _globals['_FUNCTIONCALL']._serialized_end=1527
  _globals['_CHATCOMPLETIONMESSAGETOOLCALL']._serialized_start=1529
  _globals['_CHATCOMPLETIONMESSAGETOOLCALL']._serialized_end=1623
  _globals['_FUNCTION']._serialized_start=1625
  _globals['_FUNCTION']._serialized_end=1668
  _globals['_CHATCOMPLETIONCHUNKRESPONSE']._serialized_start=1671
  _globals['_CHATCOMPLETIONCHUNKRESPONSE']._serialized_end=1890
  _globals['_CHATMESSAGE']._serialized_start=1892
  _globals['_CHATMESSAGE']._serialized_end=1936
  _globals['_CHUNKCHOICE']._serialized_start=1939
  _globals['_CHUNKCHOICE']._serialized_end=2070
  _globals['_CHOICELOGPROBS']._serialized_start=2072
  _globals['_CHOICELOGPROBS']._serialized_end=2196
  _globals['_CHOICEDELTA']._serialized_start=2199
  _globals['_CHOICEDELTA']._serialized_end=2367
  _globals['_CHOICEDELTAFUNCTIONCALL']._serialized_start=2369
  _globals['_CHOICEDELTAFUNCTIONCALL']._serialized_end=2427
  _globals['_CHOICEDELTATOOLCALL']._serialized_start=2429
  _globals['_CHOICEDELTATOOLCALL']._serialized_end=2547
  _globals['_CHOICEDELTATOOLCALLFUNCTION']._serialized_start=2549
  _globals['_CHOICEDELTATOOLCALLFUNCTION']._serialized_end=2611
  _globals['_CHATCOMPLETIONTOKENLOGPROB']._serialized_start=2613
  _globals['_CHATCOMPLETIONTOKENLOGPROB']._serialized_end=2731
  _globals['_TOPLOGPROB']._serialized_start=2733
  _globals['_TOPLOGPROB']._serialized_end=2792
  _globals['_COMPLETIONUSAGE']._serialized_start=2795
  _globals['_COMPLETIONUSAGE']._serialized_end=3014
  _globals['_COMPLETIONTOKENSDETAILS']._serialized_start=3017
  _globals['_COMPLETIONTOKENSDETAILS']._serialized_end=3162
  _globals['_PROMPTTOKENSDETAILS']._serialized_start=3164
  _globals['_PROMPTTOKENSDETAILS']._serialized_end=3230
  _globals['_WEBRETRIEVALREQUEST']._serialized_start=3233
  _globals['_WEBRETRIEVALREQUEST']._serialized_end=3452
  _globals['_WEBSEARCHRESULT']._serialized_start=3454
  _globals['_WEBSEARCHRESULT']._serialized_end=3519
  _globals['_WEBRETRIEVALRESPONSE']._serialized_start=3521
  _globals['_WEBRETRIEVALRESPONSE']._serialized_end=3586
  _globals['_SUBMITDEEPRESEARCHERJOBRESPONSE']._serialized_start=3588
  _globals['_SUBMITDEEPRESEARCHERJOBRESPONSE']._serialized_end=3693
  _globals['_GETDEEPRESEARCHERJOBRESPONSE']._serialized_start=3696
  _globals['_GETDEEPRESEARCHERJOBRESPONSE']._serialized_end=3880
  _globals['_DEEPRESEARCHERRESULTCHUNK']._serialized_start=3882
  _globals['_DEEPRESEARCHERRESULTCHUNK']._serialized_end=3940
  _globals['_GETDEEPRESEARCHERJOBREQUEST']._serialized_start=3942
  _globals['_GETDEEPRESEARCHERJOBREQUEST']._serialized_end=3987
  _globals['_CHATSESSION']._serialized_start=3990
  _globals['_CHATSESSION']._serialized_end=4162
  _globals['_GETCHATSESSIONSRESPONSE']._serialized_start=4164
  _globals['_GETCHATSESSIONSRESPONSE']._serialized_end=4234
  _globals['_UPDATECHATATTRIBUTEREQUEST']._serialized_start=4237
  _globals['_UPDATECHATATTRIBUTEREQUEST']._serialized_end=4406
  _globals['_UPDATECHATATTRIBUTEREQUEST_ATTRIBUTESENTRY']._serialized_start=4357
  _globals['_UPDATECHATATTRIBUTEREQUEST_ATTRIBUTESENTRY']._serialized_end=4406
  _globals['_UPDATECHATATTRIBUTERESPONSE']._serialized_start=4408
  _globals['_UPDATECHATATTRIBUTERESPONSE']._serialized_end=4454
  _globals['_APEXSERVICE']._serialized_start=4457
  _globals['_APEXSERVICE']._serialized_end=5103
# @@protoc_insertion_point(module_scope)
