# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: billing/v1/billing.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'billing/v1/billing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x62illing/v1/billing.proto\x12\nbilling.v1\"=\n\x0fGetUsageRequest\x12\x19\n\x0cproduct_type\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_product_type\"p\n\x0b\x42illingRate\x12\x11\n\trate_type\x18\x01 \x01(\t\x12\x11\n\tunit_size\x18\x02 \x01(\x03\x12\x11\n\tunit_type\x18\x03 \x01(\t\x12\x16\n\x0eprice_per_unit\x18\x04 \x01(\x02\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\"\x8e\x01\n\x10GetUsageResponse\x12\x19\n\x11\x61vailable_credits\x18\x01 \x01(\x02\x12\x14\n\x0cused_credits\x18\x02 \x01(\x02\x12\x19\n\x11remaining_credits\x18\x03 \x01(\x02\x12.\n\rbilling_rates\x18\x04 \x03(\x0b\x32\x17.billing.v1.BillingRate2W\n\x0e\x42illingService\x12\x45\n\x08GetUsage\x12\x1b.billing.v1.GetUsageRequest\x1a\x1c.billing.v1.GetUsageResponseB4Z2macrocosm-os/rift/constellation_api/gen/billing/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'billing.v1.billing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2macrocosm-os/rift/constellation_api/gen/billing/v1'
  _globals['_GETUSAGEREQUEST']._serialized_start=40
  _globals['_GETUSAGEREQUEST']._serialized_end=101
  _globals['_BILLINGRATE']._serialized_start=103
  _globals['_BILLINGRATE']._serialized_end=215
  _globals['_GETUSAGERESPONSE']._serialized_start=218
  _globals['_GETUSAGERESPONSE']._serialized_end=360
  _globals['_BILLINGSERVICE']._serialized_start=362
  _globals['_BILLINGSERVICE']._serialized_end=449
# @@protoc_insertion_point(module_scope)
