# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gravity/v1/gravity.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gravity/v1/gravity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gravity/v1/gravity.proto\x12\ngravity.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xab\x02\n\x07\x43rawler\x12\x12\n\ncrawler_id\x18\x01 \x01(\t\x12-\n\x08\x63riteria\x18\x02 \x01(\x0b\x32\x1b.gravity.v1.CrawlerCriteria\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13\x64\x65registration_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x61rchive_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x05state\x18\x06 \x01(\x0b\x32\x18.gravity.v1.CrawlerState\x12\x19\n\x11\x64\x61taset_workflows\x18\x07 \x03(\t\"w\n\x0f\x43rawlerCriteria\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x35\n\x0cnotification\x18\x03 \x01(\x0b\x32\x1f.gravity.v1.CrawlerNotification\x12\x0c\n\x04mock\x18\x04 \x01(\x08\"/\n\x13\x43rawlerNotification\x12\n\n\x02to\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"C\n\x06HfRepo\x12\x11\n\trepo_name\x18\x01 \x01(\t\x12\x11\n\trow_count\x18\x02 \x01(\x04\x12\x13\n\x0blast_update\x18\x03 \x01(\t\"u\n\x0c\x43rawlerState\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x17\n\x0f\x62ytes_collected\x18\x02 \x01(\x04\x12\x19\n\x11records_collected\x18\x03 \x01(\x04\x12!\n\x05repos\x18\x04 \x03(\x0b\x32\x12.gravity.v1.HfRepo\"\xbe\x01\n\x10GravityTaskState\x12\x17\n\x0fgravity_task_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x63rawler_ids\x18\x05 \x03(\t\x12.\n\x11\x63rawler_workflows\x18\x06 \x03(\x0b\x32\x13.gravity.v1.Crawler\"~\n\x16GetGravityTasksRequest\x12\x1c\n\x0fgravity_task_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x10include_crawlers\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x12\n\x10_gravity_task_idB\x13\n\x11_include_crawlers\"T\n\x17GetGravityTasksResponse\x12\x39\n\x13gravity_task_states\x18\x01 \x03(\x0b\x32\x1c.gravity.v1.GravityTaskState\".\n\x0bGravityTask\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x10\n\x08platform\x18\x02 \x01(\t\"`\n\x13NotificationRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x19\n\x0credirect_url\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_redirect_url\"\'\n\x11GetCrawlerRequest\x12\x12\n\ncrawler_id\x18\x01 \x01(\t\":\n\x12GetCrawlerResponse\x12$\n\x07\x63rawler\x18\x01 \x01(\x0b\x32\x13.gravity.v1.Crawler\"\xca\x01\n\x18\x43reateGravityTaskRequest\x12.\n\rgravity_tasks\x18\x01 \x03(\x0b\x32\x17.gravity.v1.GravityTask\x12\x0c\n\x04name\x18\x02 \x01(\t\x12>\n\x15notification_requests\x18\x03 \x03(\x0b\x32\x1f.gravity.v1.NotificationRequest\x12\x1c\n\x0fgravity_task_id\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x12\n\x10_gravity_task_id\"4\n\x19\x43reateGravityTaskResponse\x12\x17\n\x0fgravity_task_id\x18\x01 \x01(\t\"{\n\x13\x42uildDatasetRequest\x12\x12\n\ncrawler_id\x18\x01 \x01(\t\x12>\n\x15notification_requests\x18\x02 \x03(\x0b\x32\x1f.gravity.v1.NotificationRequest\x12\x10\n\x08max_rows\x18\x03 \x01(\x03\"P\n\x14\x42uildDatasetResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12$\n\x07\x64\x61taset\x18\x02 \x01(\x0b\x32\x13.gravity.v1.Dataset\"=\n\x06Nebula\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x17\n\x0f\x66ile_size_bytes\x18\x02 \x01(\x03\x12\x0b\n\x03url\x18\x03 \x01(\t\"\xb9\x02\n\x07\x44\x61taset\x12\x1b\n\x13\x63rawler_workflow_id\x18\x01 \x01(\t\x12/\n\x0b\x63reate_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x65xpire_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x05\x66iles\x18\x04 \x03(\x0b\x32\x17.gravity.v1.DatasetFile\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x16\n\x0estatus_message\x18\x06 \x01(\t\x12&\n\x05steps\x18\x07 \x03(\x0b\x32\x17.gravity.v1.DatasetStep\x12\x13\n\x0btotal_steps\x18\x08 \x01(\x03\x12\"\n\x06nebula\x18\t \x01(\x0b\x32\x12.gravity.v1.Nebula\"\x9b\x01\n\x0b\x44\x61tasetFile\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x17\n\x0f\x66ile_size_bytes\x18\x02 \x01(\x04\x12\x31\n\rlast_modified\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08num_rows\x18\x04 \x01(\x04\x12\x0e\n\x06s3_key\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\"@\n\x0b\x44\x61tasetStep\x12\x10\n\x08progress\x18\x01 \x01(\x01\x12\x0c\n\x04step\x18\x02 \x01(\x03\x12\x11\n\tstep_name\x18\x03 \x01(\t\"\'\n\x11GetDatasetRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\t\":\n\x12GetDatasetResponse\x12$\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x13.gravity.v1.Dataset\"3\n\x18\x43\x61ncelGravityTaskRequest\x12\x17\n\x0fgravity_task_id\x18\x01 \x01(\t\",\n\x19\x43\x61ncelGravityTaskResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"*\n\x14\x43\x61ncelDatasetRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\t\"(\n\x15\x43\x61ncelDatasetResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"X\n\x1f\x44\x61tasetBillingCorrectionRequest\x12\x1b\n\x13requested_row_count\x18\x01 \x01(\x03\x12\x18\n\x10\x61\x63tual_row_count\x18\x02 \x01(\x03\"9\n DatasetBillingCorrectionResponse\x12\x15\n\rrefund_amount\x18\x01 \x01(\x01\x32\xea\x05\n\x0eGravityService\x12Z\n\x0fGetGravityTasks\x12\".gravity.v1.GetGravityTasksRequest\x1a#.gravity.v1.GetGravityTasksResponse\x12K\n\nGetCrawler\x12\x1d.gravity.v1.GetCrawlerRequest\x1a\x1e.gravity.v1.GetCrawlerResponse\x12`\n\x11\x43reateGravityTask\x12$.gravity.v1.CreateGravityTaskRequest\x1a%.gravity.v1.CreateGravityTaskResponse\x12Q\n\x0c\x42uildDataset\x12\x1f.gravity.v1.BuildDatasetRequest\x1a .gravity.v1.BuildDatasetResponse\x12K\n\nGetDataset\x12\x1d.gravity.v1.GetDatasetRequest\x1a\x1e.gravity.v1.GetDatasetResponse\x12`\n\x11\x43\x61ncelGravityTask\x12$.gravity.v1.CancelGravityTaskRequest\x1a%.gravity.v1.CancelGravityTaskResponse\x12T\n\rCancelDataset\x12 .gravity.v1.CancelDatasetRequest\x1a!.gravity.v1.CancelDatasetResponse\x12u\n\x18\x44\x61tasetBillingCorrection\x12+.gravity.v1.DatasetBillingCorrectionRequest\x1a,.gravity.v1.DatasetBillingCorrectionResponseB4Z2macrocosm-os/rift/constellation_api/gen/gravity/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gravity.v1.gravity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2macrocosm-os/rift/constellation_api/gen/gravity/v1'
  _globals['_CRAWLER']._serialized_start=74
  _globals['_CRAWLER']._serialized_end=373
  _globals['_CRAWLERCRITERIA']._serialized_start=375
  _globals['_CRAWLERCRITERIA']._serialized_end=494
  _globals['_CRAWLERNOTIFICATION']._serialized_start=496
  _globals['_CRAWLERNOTIFICATION']._serialized_end=543
  _globals['_HFREPO']._serialized_start=545
  _globals['_HFREPO']._serialized_end=612
  _globals['_CRAWLERSTATE']._serialized_start=614
  _globals['_CRAWLERSTATE']._serialized_end=731
  _globals['_GRAVITYTASKSTATE']._serialized_start=734
  _globals['_GRAVITYTASKSTATE']._serialized_end=924
  _globals['_GETGRAVITYTASKSREQUEST']._serialized_start=926
  _globals['_GETGRAVITYTASKSREQUEST']._serialized_end=1052
  _globals['_GETGRAVITYTASKSRESPONSE']._serialized_start=1054
  _globals['_GETGRAVITYTASKSRESPONSE']._serialized_end=1138
  _globals['_GRAVITYTASK']._serialized_start=1140
  _globals['_GRAVITYTASK']._serialized_end=1186
  _globals['_NOTIFICATIONREQUEST']._serialized_start=1188
  _globals['_NOTIFICATIONREQUEST']._serialized_end=1284
  _globals['_GETCRAWLERREQUEST']._serialized_start=1286
  _globals['_GETCRAWLERREQUEST']._serialized_end=1325
  _globals['_GETCRAWLERRESPONSE']._serialized_start=1327
  _globals['_GETCRAWLERRESPONSE']._serialized_end=1385
  _globals['_CREATEGRAVITYTASKREQUEST']._serialized_start=1388
  _globals['_CREATEGRAVITYTASKREQUEST']._serialized_end=1590
  _globals['_CREATEGRAVITYTASKRESPONSE']._serialized_start=1592
  _globals['_CREATEGRAVITYTASKRESPONSE']._serialized_end=1644
  _globals['_BUILDDATASETREQUEST']._serialized_start=1646
  _globals['_BUILDDATASETREQUEST']._serialized_end=1769
  _globals['_BUILDDATASETRESPONSE']._serialized_start=1771
  _globals['_BUILDDATASETRESPONSE']._serialized_end=1851
  _globals['_NEBULA']._serialized_start=1853
  _globals['_NEBULA']._serialized_end=1914
  _globals['_DATASET']._serialized_start=1917
  _globals['_DATASET']._serialized_end=2230
  _globals['_DATASETFILE']._serialized_start=2233
  _globals['_DATASETFILE']._serialized_end=2388
  _globals['_DATASETSTEP']._serialized_start=2390
  _globals['_DATASETSTEP']._serialized_end=2454
  _globals['_GETDATASETREQUEST']._serialized_start=2456
  _globals['_GETDATASETREQUEST']._serialized_end=2495
  _globals['_GETDATASETRESPONSE']._serialized_start=2497
  _globals['_GETDATASETRESPONSE']._serialized_end=2555
  _globals['_CANCELGRAVITYTASKREQUEST']._serialized_start=2557
  _globals['_CANCELGRAVITYTASKREQUEST']._serialized_end=2608
  _globals['_CANCELGRAVITYTASKRESPONSE']._serialized_start=2610
  _globals['_CANCELGRAVITYTASKRESPONSE']._serialized_end=2654
  _globals['_CANCELDATASETREQUEST']._serialized_start=2656
  _globals['_CANCELDATASETREQUEST']._serialized_end=2698
  _globals['_CANCELDATASETRESPONSE']._serialized_start=2700
  _globals['_CANCELDATASETRESPONSE']._serialized_end=2740
  _globals['_DATASETBILLINGCORRECTIONREQUEST']._serialized_start=2742
  _globals['_DATASETBILLINGCORRECTIONREQUEST']._serialized_end=2830
  _globals['_DATASETBILLINGCORRECTIONRESPONSE']._serialized_start=2832
  _globals['_DATASETBILLINGCORRECTIONRESPONSE']._serialized_end=2889
  _globals['_GRAVITYSERVICE']._serialized_start=2892
  _globals['_GRAVITYSERVICE']._serialized_end=3638
# @@protoc_insertion_point(module_scope)
